From 3096d4eec1e00bdc518baf53e4fddd884b4f64ce Mon Sep 17 00:00:00 2001
From: "Devin J. Pohly" <djpohly@gmail.com>
Date: Sat, 2 May 2020 15:22:07 -0500
Subject: set default cursor over window borders

---
 dwl.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/dwl.c b/dwl.c
index 709c384..68a1d5e 100644
--- a/dwl.c
+++ b/dwl.c
@@ -725,10 +725,10 @@ motionnotify(uint32_t time)
 
 	/* Otherwise, find the client under the pointer and send the event along. */
 	c = xytoclient(cursor->x, cursor->y, &surface, &sx, &sy);
 	/* If there's no client under the cursor, set the cursor image to a
 	 * default. This is what makes the cursor image appear when you move it
-	 * around the screen, not over any clients. */
-	if (!c)
+	 * off of a client or over its border. */
+	if (!surface)
 		wlr_xcursor_manager_set_cursor_image(cursor_mgr,
 				"left_ptr", cursor);
 
@@ -725,10 +725,10 @@ motionnotify(uint32_t time)
 	/* Otherwise, find the client under the pointer and send the event along. */
 	c = xytoclient(cursor->x, cursor->y, &surface, &sx, &sy);
-	/* If there's no client under the cursor, set the cursor image to a
+	/* If there's no client surface under the cursor, set the cursor image to a
 	 * default. This is what makes the cursor image appear when you move it
-- 
cgit v1.2.3